import { Context, HTTPClient } from 'koajax';
import { UploadTargetType, UserMeta } from './type';
export interface LarkAppOption {
    host?: string;
    id: string;
    secret?: string;
}
export declare class LarkApp implements LarkAppOption {
    host?: string;
    id: string;
    secret?: string;
    client: HTTPClient<Context>;
    accessToken?: string;
    constructor({ host, id, secret }: LarkAppOption);
    private boot;
    getAccessToken(): Promise<string>;
    /**
     * Back-end only
     *
     * @see {@link https://open.feishu.cn/document/ukTMukTMukTM/ukDNz4SO0MjL5QzM/auth-v3/auth/tenant_access_token_internal}
     */
    getTenantAccessToken: (...data: never[]) => Promise<string>;
    /**
     * @see {@link https://open.feishu.cn/document/ukTMukTMukTM/ukzN4UjL5cDO14SO3gTN}
     */
    getWebSignInURL(redirect_uri: string, state?: string): string;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/authen-v1/authen/access_token}
     */
    getUserMeta(code: string): Promise<UserMeta | undefined>;
    /**
     * @see {@link https://open.feishu.cn/document/ukTMukTMukTM/uYTM5UjL2ETO14iNxkTN/h5_js_sdk/authorization}
     */
    getJSTicket: (...data: never[]) => Promise<string>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/drive-v1/media/download}
     */
    downloadFile(id: string): Promise<ArrayBuffer>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/drive-v1/media/upload_all}
     */
    uploadFile(file: File, parent_type: UploadTargetType, parent_node: string): Promise<string>;
}
