import { ListModel, NewData } from 'mobx-restful';
import { ChatMessage, ChatMeta, SendChatMessage } from './type';
export * from './type';
declare const ChatListModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<ChatMeta, void, any> | undefined;
    openStream(filter: Partial<NewData<ChatMeta>>): AsyncGenerator<ChatMeta, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<ChatMeta, Partial<NewData<ChatMeta>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">> | undefined): Promise<void>;
    loadStream(filter: Partial<NewData<ChatMeta>>, newCount: number): Promise<ChatMeta[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<ChatMeta>>): Promise<{
        pageData: ChatMeta[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<ChatMeta>>;
    totalCount: number | undefined;
    pageList: ChatMeta[][];
    readonly currentPage: ChatMeta[];
    readonly pageCount: number;
    readonly allItems: ChatMeta[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<ChatMeta, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<ChatMeta, Partial<NewData<ChatMeta>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<ChatMeta>>): Promise<{
        pageData: ChatMeta[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<ChatMeta>> | undefined, pageIndex?: number, pageSize?: number): Promise<ChatMeta[]>;
    refreshList(): Promise<ChatMeta[]>;
    getAll(filter?: Partial<NewData<ChatMeta>> | undefined, pageSize?: number): Promise<ChatMeta[]>;
    countAll(keys: import("web-utility").TypeKeys<ChatMeta, import("web-utility").IndexKey>[], filter?: Partial<NewData<ChatMeta>> | undefined, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<ChatMeta, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: import("mobx-restful").IDType): number;
    changeOne(data: Partial<ChatMeta>, id: import("mobx-restful").IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<ChatMeta>>, id?: import("mobx-restful").IDType): Promise<ChatMeta>;
    removeOne(id: import("mobx-restful").IDType): Promise<void>;
    deleteOne(id: import("mobx-restful").IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: keyof ChatMeta;
    currentOne: ChatMeta;
    clearCurrent(): void;
    getOne(id: import("mobx-restful").IDType): Promise<ChatMeta>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<ChatMeta, Partial<NewData<ChatMeta>>>>;
export declare abstract class ChatListModel extends ChatListModel_base {
    baseURI: string;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/chat/list}
     */
    openStream(): AsyncGenerator<ChatMeta, void, unknown>;
    /**
     * @see https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/chat/create
     */
    updateOne({ chat_id }: NewData<ChatMeta>): Promise<ChatMeta>;
}
declare const MessageListModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<ChatMessage, void, any> | undefined;
    openStream(filter: Partial<NewData<ChatMessage>>): AsyncGenerator<ChatMessage, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<ChatMessage, Partial<NewData<ChatMessage>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">> | undefined): Promise<void>;
    loadStream(filter: Partial<NewData<ChatMessage>>, newCount: number): Promise<ChatMessage[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<ChatMessage>>): Promise<{
        pageData: ChatMessage[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<ChatMessage>>;
    totalCount: number | undefined;
    pageList: ChatMessage[][];
    readonly currentPage: ChatMessage[];
    readonly pageCount: number;
    readonly allItems: ChatMessage[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<ChatMessage, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<ChatMessage, Partial<NewData<ChatMessage>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<ChatMessage>>): Promise<{
        pageData: ChatMessage[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<ChatMessage>> | undefined, pageIndex?: number, pageSize?: number): Promise<ChatMessage[]>;
    refreshList(): Promise<ChatMessage[]>;
    getAll(filter?: Partial<NewData<ChatMessage>> | undefined, pageSize?: number): Promise<ChatMessage[]>;
    countAll(keys: import("web-utility").TypeKeys<ChatMessage, import("web-utility").IndexKey>[], filter?: Partial<NewData<ChatMessage>> | undefined, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<ChatMessage, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: import("mobx-restful").IDType): number;
    changeOne(data: Partial<ChatMessage>, id: import("mobx-restful").IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<ChatMessage>>, id?: import("mobx-restful").IDType): Promise<ChatMessage>;
    removeOne(id: import("mobx-restful").IDType): Promise<void>;
    deleteOne(id: import("mobx-restful").IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: keyof ChatMessage;
    currentOne: ChatMessage;
    clearCurrent(): void;
    getOne(id: import("mobx-restful").IDType): Promise<ChatMessage>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<ChatMessage, Partial<NewData<ChatMessage>>>>;
export declare abstract class MessageListModel extends MessageListModel_base {
    chatId: string;
    baseURI: string;
    constructor(chatId: string);
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/message/list}
     */
    openStream(): AsyncGenerator<ChatMessage, void, unknown>;
    /**
     * @see https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/message/create
     */
    createOne({ msg_type, content }: Omit<SendChatMessage, 'receive_id'>): Promise<ChatMessage>;
}
