import { Filter, IDType, ListModel, NewData } from 'mobx-restful';
import { UserIdType } from '../../type';
import { Task, TaskField, TaskList, TaskListSection, TaskResource } from './type';
export * from './type';
export interface BaseTaskFilter {
    user_id_type?: UserIdType;
}
export interface TaskFilter extends Filter<Task>, BaseTaskFilter, Partial<TaskResource>, Record<`created_${'from' | 'to'}`, string> {
    completed?: boolean;
}
declare const TaskModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Task, void, any> | undefined;
    openStream(filter: TaskFilter): AsyncGenerator<Task, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Task, Partial<NewData<Task>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">> | undefined): Promise<void>;
    loadStream(filter: TaskFilter, newCount: number): Promise<Task[]>;
    loadPage(pageIndex: number, pageSize: number, filter: TaskFilter): Promise<{
        pageData: Task[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: TaskFilter;
    totalCount: number | undefined;
    pageList: Task[][];
    readonly currentPage: Task[];
    readonly pageCount: number;
    readonly allItems: Task[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<Task, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Task, TaskFilter>;
    loadNewPage(pageIndex: number, pageSize: number, filter: TaskFilter): Promise<{
        pageData: Task[];
        totalCount: number;
    }>;
    getList(filter?: TaskFilter | undefined, pageIndex?: number, pageSize?: number): Promise<Task[]>;
    refreshList(): Promise<Task[]>;
    getAll(filter?: TaskFilter | undefined, pageSize?: number): Promise<Task[]>;
    countAll(keys: import("web-utility").TypeKeys<Task, import("web-utility").IndexKey>[], filter?: TaskFilter | undefined, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<Task, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<Task>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<Task>>, id?: IDType): Promise<Task>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: keyof Task;
    currentOne: Task;
    clearCurrent(): void;
    getOne(id: IDType): Promise<Task>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<Task, TaskFilter>>;
export declare abstract class TaskModel extends TaskModel_base {
    baseURI: string;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/task/list}
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/tasklist/tasks}
     */
    openStream({ resource_type, resource_id, user_id_type, ...rest }: TaskFilter): AsyncGenerator<Task, void, unknown>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/task/get}
     */
    getOne(id: string, user_id_type?: UserIdType): Promise<Task>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/task/create}
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/task/patch}
     */
    updateOne(task: NewData<Task>, id?: string, user_id_type?: UserIdType): Promise<Task>;
}
export type TaskListFilter = Filter<TaskList> & BaseTaskFilter;
declare const TaskListModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<TaskList, void, any> | undefined;
    openStream(filter: TaskListFilter): AsyncGenerator<TaskList, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<TaskList, Partial<NewData<TaskList>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">> | undefined): Promise<void>;
    loadStream(filter: TaskListFilter, newCount: number): Promise<TaskList[]>;
    loadPage(pageIndex: number, pageSize: number, filter: TaskListFilter): Promise<{
        pageData: TaskList[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: TaskListFilter;
    totalCount: number | undefined;
    pageList: TaskList[][];
    readonly currentPage: TaskList[];
    readonly pageCount: number;
    readonly allItems: TaskList[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<TaskList, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<TaskList, TaskListFilter>;
    loadNewPage(pageIndex: number, pageSize: number, filter: TaskListFilter): Promise<{
        pageData: TaskList[];
        totalCount: number;
    }>;
    getList(filter?: TaskListFilter | undefined, pageIndex?: number, pageSize?: number): Promise<TaskList[]>;
    refreshList(): Promise<TaskList[]>;
    getAll(filter?: TaskListFilter | undefined, pageSize?: number): Promise<TaskList[]>;
    countAll(keys: import("web-utility").TypeKeys<TaskList, import("web-utility").IndexKey>[], filter?: TaskListFilter | undefined, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<TaskList, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<TaskList>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<TaskList>>, id?: IDType): Promise<TaskList>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: keyof TaskList;
    currentOne: TaskList;
    clearCurrent(): void;
    getOne(id: IDType): Promise<TaskList>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<TaskList, TaskListFilter>>;
export declare abstract class TaskListModel extends TaskListModel_base {
    baseURI: string;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/tasklist/list}
     */
    openStream({ user_id_type }: TaskListFilter): AsyncGenerator<TaskList, void, unknown>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/tasklist/get}
     */
    getOne(id: IDType, user_id_type?: UserIdType): Promise<TaskList>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/tasklist/create}
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/tasklist/patch}
     */
    updateOne(tasklist: NewData<TaskList>, id?: string, user_id_type?: UserIdType): Promise<TaskList>;
}
export type TaskListSectionFilter = Partial<TaskResource> & BaseTaskFilter;
declare const TaskListSectionModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<TaskListSection, void, any> | undefined;
    openStream(filter: TaskListSectionFilter): AsyncGenerator<TaskListSection, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<TaskListSection, Partial<NewData<TaskListSection>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">> | undefined): Promise<void>;
    loadStream(filter: TaskListSectionFilter, newCount: number): Promise<TaskListSection[]>;
    loadPage(pageIndex: number, pageSize: number, filter: TaskListSectionFilter): Promise<{
        pageData: TaskListSection[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: TaskListSectionFilter;
    totalCount: number | undefined;
    pageList: TaskListSection[][];
    readonly currentPage: TaskListSection[];
    readonly pageCount: number;
    readonly allItems: TaskListSection[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<TaskListSection, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<TaskListSection, TaskListSectionFilter>;
    loadNewPage(pageIndex: number, pageSize: number, filter: TaskListSectionFilter): Promise<{
        pageData: TaskListSection[];
        totalCount: number;
    }>;
    getList(filter?: TaskListSectionFilter | undefined, pageIndex?: number, pageSize?: number): Promise<TaskListSection[]>;
    refreshList(): Promise<TaskListSection[]>;
    getAll(filter?: TaskListSectionFilter | undefined, pageSize?: number): Promise<TaskListSection[]>;
    countAll(keys: import("web-utility").TypeKeys<TaskListSection, import("web-utility").IndexKey>[], filter?: TaskListSectionFilter | undefined, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<TaskListSection, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<TaskListSection>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<TaskListSection>>, id?: IDType): Promise<TaskListSection>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: keyof TaskListSection;
    currentOne: TaskListSection;
    clearCurrent(): void;
    getOne(id: IDType): Promise<TaskListSection>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<TaskListSection, TaskListSectionFilter>>;
export declare abstract class TaskListSectionModel extends TaskListSectionModel_base {
    baseURI: string;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/section/list}
     */
    openStream({ resource_type, resource_id, user_id_type }: TaskListSectionFilter): AsyncGenerator<TaskListSection, void, unknown>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/section/get}
     */
    getOne(id: string): Promise<TaskListSection>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/section/create}
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/section/patch}
     */
    updateOne(section: NewData<TaskListSection>, id?: string, user_id_type?: UserIdType, [target]?: Partial<TaskResource>[]): Promise<TaskListSection>;
}
export type TaskFieldFilter = Filter<TaskField> & Partial<TaskListSectionFilter>;
declare const TaskFieldModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<TaskField, void, any> | undefined;
    openStream(filter: TaskFieldFilter): AsyncGenerator<TaskField, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<TaskField, Partial<NewData<TaskField>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">> | undefined): Promise<void>;
    loadStream(filter: TaskFieldFilter, newCount: number): Promise<TaskField[]>;
    loadPage(pageIndex: number, pageSize: number, filter: TaskFieldFilter): Promise<{
        pageData: TaskField[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: TaskFieldFilter;
    totalCount: number | undefined;
    pageList: TaskField[][];
    readonly currentPage: TaskField[];
    readonly pageCount: number;
    readonly allItems: TaskField[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<TaskField, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<TaskField, TaskFieldFilter>;
    loadNewPage(pageIndex: number, pageSize: number, filter: TaskFieldFilter): Promise<{
        pageData: TaskField[];
        totalCount: number;
    }>;
    getList(filter?: TaskFieldFilter | undefined, pageIndex?: number, pageSize?: number): Promise<TaskField[]>;
    refreshList(): Promise<TaskField[]>;
    getAll(filter?: TaskFieldFilter | undefined, pageSize?: number): Promise<TaskField[]>;
    countAll(keys: import("web-utility").TypeKeys<TaskField, import("web-utility").IndexKey>[], filter?: TaskFieldFilter | undefined, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<TaskField, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<TaskField>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<TaskField>>, id?: IDType): Promise<TaskField>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: "name" | "creator" | "guid" | "created_at" | "updated_at" | "type";
    currentOne: TaskField;
    clearCurrent(): void;
    getOne(id: IDType): Promise<TaskField>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<TaskField, TaskFieldFilter>>;
export declare abstract class TaskFieldModel extends TaskFieldModel_base {
    baseURI: string;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/custom_field/list}
     */
    openStream({ resource_type, resource_id, user_id_type }: TaskFieldFilter): AsyncGenerator<TaskField, void, unknown>;
    /**
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/custom_field/create}
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/custom_field/patch}
     * @see {@link https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/task-v2/custom_field/add}
     */
    updateOne(data: NewData<TaskField>, id?: string, user_id_type?: UserIdType, [target, ...targets]?: TaskResource[]): Promise<TaskField>;
}
